#include <stdio.h>
#include <string.h>
#include <ctype.h>

enum protein {beef, chicken, veggie};

enum topping { cheese, lettuce, tomato, onion, pickle};

enum side { fries, salad, fruit};

enum drink { water, coke, pepsi, diet, orange};

#define MAX_TOPPINGS 6

struct sandwich
{
    enum protein type;
    enum topping extras[MAX_TOPPINGS];
    int numToppings;
};

struct meal
{
    struct sandwich entree;
    enum drink beverage;
    enum side accompaniment;
};

void getToppings(struct sandwich *);
enum side getSide();
enum drink getDrink();
void printOrder (struct meal);

int main()
{
    int numMeals;
    printf("Enter the number of meals to order: ");
    scanf("%d", &numMeals);

    struct meal order[numMeals];

    for (int i = 0; i < numMeals; i++)
    {
        printf("Collecting information for meal %d:\n", i+1);
        struct meal current;
        struct sandwich sand;
        sand.numToppings = 0; /* Initialize the sandwich */

        char meat[8];
        printf("What kind of sandwich would you like? ");
        scanf("%s", meat);

        if (strcmp("beef", meat) == 0)
        {
            sand.type = beef;
        }
        else if (strcmp("chicken", meat) == 0)
        {
            sand.type = chicken;
        }
        else
        {
            sand.type = veggie;
        }

        getToppings(&sand);

        current.entree = sand;

        current.accompaniment = getSide();
        current.beverage = getDrink();

        order[i] = current;
    }

    for (int k = 0; k < numMeals; k++)
    {
        printOrder(order[k]);
        printf("\n");
    }

    return 0;
}

void getToppings(struct sandwich * s)
{
    while (s->numToppings < MAX_TOPPINGS)
    {
        printf("1: Add cheese\n");
        printf("2: Add lettuce\n");
        printf("3: Add tomato\n");
        printf("4: Add onion\n");
        printf("5: Add pickle\n");
        printf("0: Stop adding toppings\n\n");

        int choice;
        scanf("%d", &choice);

        if (choice == 0)
        {
            break;
        }
        else
        {
            switch(choice)
            {
                case 1: s->extras[s->numToppings] = cheese;
                        printf("Added cheese.\n");
                        break;
                case 2: s->extras[s->numToppings] = lettuce;
                printf("Added lettuce.\n");
                break;
                case 3: s->extras[s->numToppings] = tomato;
                printf("Added tomato.\n");
                break;
                case 4: s->extras[s->numToppings] = onion;
                printf("Added onion.\n");
                break;
                case 5: s->extras[s->numToppings] = pickle;
                printf("Added pickle.\n");
            }
            (s->numToppings)++;
        }
    }
}

void printOrder(struct meal m)
{
    printf("You ordered a ");

    if (m.entree.type == beef)
    {
        printf("hamburger");
    }
    else if (m.entree.type == chicken)
    {
        printf("chicken sandwich");
    }
    else
    {
        printf("veggie burger");
    }

    if (m.entree.numToppings > 0)
    {
      printf(" with");

      for (int i = 0; i < m.entree.numToppings; i++)
      {
        /* Remember that enumeration type tags are really integers */
        enum topping nextExtra = m.entree.extras[i];

        /* Add nice formatting for the final topping */
        if (m.entree.numToppings > 1 && i == m.entree.numToppings - 1)
        {
          printf(" and");
        }

        switch(nextExtra)
        {
          case cheese:  printf(" cheese"); break;
          case lettuce: printf(" lettuce"); break;
          case tomato:  printf(" tomato"); break;
          case onion:   printf(" onion"); break;
          case pickle:  printf(" pickle");
        }

        /* Add commas between non-final elements */
        if (i < m.entree.numToppings - 2)
        {
          printf(",");
        }
      }
    }

    printf(".\nThis comes with a glass of ");
    if (m.beverage == coke)
    {
        printf("Coke");
    }
    else if (m.beverage == pepsi)
    {
        printf("Pepsi");
    }
    else if (m.beverage == diet)
    {
        printf("Diet Coke");
    }
    else if (m.beverage == orange)
    {
        printf("orange soda");
    }
    else if (m.beverage == water)
    {
        printf("water");
    }

    printf(" and a ");
    if (m.accompaniment == fries)
    {
        printf("side of fries");
    }
    else if (m.accompaniment == salad)
    {
        printf("side salad");
    }
    else if (m.accompaniment == fruit)
    {
        printf("cup of fruit");
    }

    printf(".\n\n");
}

enum side getSide()
{
  int sideChoice = -1;
  do
  {
    printf("Please select a side from the following choices:\n");
    printf("1. Fries\n");
    printf("2. Side salad\n");
    printf("3. Fruit cup\n");

    scanf("%d", &sideChoice);
  } while(sideChoice < 1 || sideChoice > 3);

  if (sideChoice == 1)
    return fries;
  else if (sideChoice == 2)
    return salad;
  else
    return fruit;
}

enum drink getDrink()
{
  int drinkChoice = -1;
  do
  {
    printf("Please select a drink from the following choices:\n");
    printf("1. Coke\n");
    printf("2. Pepsi\n");
    printf("3. Diet Coke\n");
    printf("4. Orange soda\n");
    printf("5. Water\n");

    scanf("%d", &drinkChoice);
  } while(drinkChoice < 1 || drinkChoice > 5);

  if (drinkChoice == 1)
    return coke;
  else if (drinkChoice == 2)
    return pepsi;
  else if (drinkChoice == 3)
    return diet;
  else if (drinkChoice == 4)
    return orange;
  else
    return water;
}
